@@ -411,6 +411,7 @@ class _LDAPUser(object):
         AuthenticationFailed on failure.
         """
         self._check_required_group()
+        self._check_denied_group()
 
     def _check_required_group(self):
         """
@@ -424,6 +425,22 @@ class _LDAPUser(object):
             if not is_member:
                 raise self.AuthenticationFailed("User is not a member of AUTH_LDAP_REQUIRE_GROUP")
 
+        return True
+
+    def _check_denied_group(self):
+        """
+        Returns True if the negative group requirement (AUTH_LDAP_DENY_GROUP)
+        is met. Always returns True if AUTH_LDAP_DENY_GROUP is None.
+        """
+        denied_group_dn = ldap_settings.AUTH_LDAP_DENY_GROUP
+
+        if denied_group_dn is not None:
+            is_member = self._get_groups().is_member_of(denied_group_dn)
+            if is_member:
+                raise self.AuthenticationFailed("User is a member of AUTH_LDAP_DENY_GROUP")
+
+        return True
+
     #
     # User management
     #
@@ -747,6 +764,7 @@ class LDAPSettings(object):
         'AUTH_LDAP_BIND_PASSWORD': '',
         'AUTH_LDAP_CACHE_GROUPS': False,
         'AUTH_LDAP_CONNECTION_OPTIONS': {},
+        'AUTH_LDAP_DENY_GROUP': None,
         'AUTH_LDAP_FIND_GROUP_PERMS': False,
         'AUTH_LDAP_GLOBAL_OPTIONS': {},
         'AUTH_LDAP_GROUP_CACHE_TIMEOUT': None,
